@@ -1,6 +1,8 @@
 context("Statement tests")
 test_that("redland library loads", {
   library(redland)
+  # Add a line to this test to prevent 'Empty test' (skipped) msg.
+  expect_true(require(redland))
 })
 test_that("Statement constructor", {
   library(redland)
@@ -9,28 +11,28 @@ test_that("Statement constructor", {
   
   # Test creating Subject, predicate, and object Nodes
   subject <- new("Node", world, literal="subject")
-  expect_that(class(subject@librdf_node), matches("_p_librdf_node_s"))
+  expect_match(class(subject@librdf_node), "_p_librdf_node_s")
   predicate <- new("Node", world, literal="subject")
-  expect_that(class(predicate@librdf_node), matches("_p_librdf_node_s"))
+  expect_match(class(predicate@librdf_node), "_p_librdf_node_s")
   object <- new("Node", world, literal="subject")
-  expect_that(class(object@librdf_node), matches("_p_librdf_node_s"))
+  expect_match(class(object@librdf_node), "_p_librdf_node_s")
   
   # Test creating the Statement
   stmt <- new("Statement", world, subject, predicate, object)
   expect_false(is.null(stmt))
-  expect_that(class(stmt@librdf_statement), matches("_p_librdf_statement_s"))
+  expect_match(class(stmt@librdf_statement), "_p_librdf_statement_s")
   
   # Test that statement creation fails if world is not provided or is null
   err <- try(stmt <- new("Statement", world=NULL, subject=subject, predicate=predicate, object=object), silent=TRUE)
-  expect_that(class(err), matches("try-error"))
+  expect_match(class(err), "try-error")
   
   # Test that statement creation fails if subject, predicate, or object is not provided or is null
   err <- try(stmt <- new("Statement", world=world, subject=NULL, predicate=predicate, object=object), silent=TRUE)
-  expect_that(class(err), matches("try-error"))
+  expect_match(class(err), "try-error")
   err <- try(stmt <- new("Statement", world=world, subject=subject, predicate=NULL, object=object), silent=TRUE)
-  expect_that(class(err), matches("try-error"))
+  expect_match(class(err), "try-error")
   err <- try(stmt <- new("Statement", world=world, subject=subject, predicate=predicate, object=NULL), silent=TRUE)
-  expect_that(class(err), matches("try-error"))
+  expect_match(class(err), "try-error")
   
   # Test statement creation when subject, predicate, object are passed in as character and RDF type is not specified
   stmt <- new("Statement", world=world, 
@@ -38,9 +40,9 @@ test_that("Statement constructor", {
               predicate="http://purl.org/dc/terms/identifier",
               object="resourceMap_5cbcdecd-6b0e-4b24-a0be-20291b2e49a7^^xsd:string")
               
-  expect_that(getTermType(stmt, "subject"), matches("resource"))
-  expect_that(getTermType(stmt, "predicate"), matches("resource"))
-  expect_that(getTermType(stmt, "object"), matches("literal"))
+  expect_match(getTermType(stmt, "subject"), "resource")
+  expect_match(getTermType(stmt, "predicate"), "resource")
+  expect_match(getTermType(stmt, "object"), "literal")
   
   # Test 
   stmt <- new("Statement", world=world, 
@@ -48,9 +50,9 @@ test_that("Statement constructor", {
               predicate="http://purl.org/dc/terms/identifier",
               object=NULL)
   
-  expect_that(getTermType(stmt, "subject"), matches("blank"))
-  expect_that(getTermType(stmt, "predicate"), matches("resource"))
-  expect_that(getTermType(stmt, "object"), matches("blank"))
+  expect_match(getTermType(stmt, "subject"), "blank")
+  expect_match(getTermType(stmt, "predicate"), "resource")
+  expect_match(getTermType(stmt, "object"), "blank")
   
   err <- try(freeStatement(stmt), silent=TRUE)
   expect_false(class(err) == "try-error")
@@ -60,9 +62,9 @@ test_that("Statement constructor", {
               predicate="http://purl.org/dc/terms/identifier",
               object="id1234")
   
-  expect_that(getTermType(stmt, "subject"), matches("blank"))
-  expect_that(getTermType(stmt, "predicate"), matches("resource"))
-  expect_that(getTermType(stmt, "object"), matches("literal"))
+  expect_match(getTermType(stmt, "subject"), "blank")
+  expect_match(getTermType(stmt, "predicate"), "resource")
+  expect_match(getTermType(stmt, "object"), "literal")
   
   err <- try(freeStatement(stmt), silent=TRUE)
   expect_false(class(err) == "try-error")
@@ -73,9 +75,9 @@ test_that("Statement constructor", {
               predicate="http://purl.org/dc/terms/identifier",
               object="http://www.exmaple.com/object", subjectType="blank", objectType="literal")
   
-  expect_that(getTermType(stmt, "subject"), matches("blank"))
-  expect_that(getTermType(stmt, "predicate"), matches("resource"))
-  expect_that(getTermType(stmt, "object"), matches("literal"))
+  expect_match(getTermType(stmt, "subject"), "blank")
+  expect_match(getTermType(stmt, "predicate"), "resource")
+  expect_match(getTermType(stmt, "object"), "literal")
   
   err <- try(freeStatement(stmt), silent=TRUE)
   expect_false(class(err) == "try-error")
